==> cxf-systests-jaxrs-4.0.10-sources.jar: org/apache/cxf/systest/jaxrs/codegen/schema/ObjectFactory.java <==

package org.apache.cxf.systest.jaxrs.codegen.schema;

import javax.xml.namespace.QName;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.cxf.systest.jaxrs.codegen.schema package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Thechapter_QNAME = new QName("http://superbooks", "thechapter");
    private final static QName _Thebook_QNAME = new QName("http://superbooks", "thebook");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.cxf.systest.jaxrs.codegen.schema
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Chapter }
     * 
     */
    public Chapter createChapter() {
        return new Chapter();
    }

    /**
     * Create an instance of {@link Book }
     * 
     */
    public Book createBook() {
        return new Book();
    }

    /**
     * Create an instance of {@link Book2 }
     * 
     */
    public Book2 createBook2() {
        return new Book2();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Chapter }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Chapter }{@code >}
     */
    @XmlElementDecl(namespace = "http://superbooks", name = "thechapter")
    public JAXBElement<Chapter> createThechapter(Chapter value) {
        return new JAXBElement<Chapter>(_Thechapter_QNAME, Chapter.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Book }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Book }{@code >}
     */
    @XmlElementDecl(namespace = "http://superbooks", name = "thebook")
    public JAXBElement<Book> createThebook(Book value) {
        return new JAXBElement<Book>(_Thebook_QNAME, Book.class, null, value);
    }

}

==> cxf-systests-jaxrs-4.1.0-sources.jar: org/apache/cxf/systest/jaxrs/codegen/schema/ObjectFactory.java <==

package org.apache.cxf.systest.jaxrs.codegen.schema;

import javax.xml.namespace.QName;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.cxf.systest.jaxrs.codegen.schema package. 
 * <p>An ObjectFactory allows you to programmatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private static final QName _Thechapter_QNAME = new QName("http://superbooks", "thechapter");
    private static final QName _Thebook_QNAME = new QName("http://superbooks", "thebook");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.cxf.systest.jaxrs.codegen.schema
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Chapter }
     * 
     * @return
     *     the new instance of {@link Chapter }
     */
    public Chapter createChapter() {
        return new Chapter();
    }

    /**
     * Create an instance of {@link Book }
     * 
     * @return
     *     the new instance of {@link Book }
     */
    public Book createBook() {
        return new Book();
    }

    /**
     * Create an instance of {@link Book2 }
     * 
     * @return
     *     the new instance of {@link Book2 }
     */
    public Book2 createBook2() {
        return new Book2();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Chapter }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Chapter }{@code >}
     */
    @XmlElementDecl(namespace = "http://superbooks", name = "thechapter")
    public JAXBElement<Chapter> createThechapter(Chapter value) {
        return new JAXBElement<>(_Thechapter_QNAME, Chapter.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Book }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Book }{@code >}
     */
    @XmlElementDecl(namespace = "http://superbooks", name = "thebook")
    public JAXBElement<Book> createThebook(Book value) {
        return new JAXBElement<>(_Thebook_QNAME, Book.class, null, value);
    }

}
